Index: trunk/MagicSoft/Mars/manalysis/MCompProbCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MCompProbCalc.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/manalysis/MCompProbCalc.cc	(revision 8074)
@@ -40,5 +40,5 @@
 
 #include "MParList.h"
-#include "MDataChain.h"
+#include "MDataPhrase.h"
 
 #include "MHCompProb.h"
@@ -113,5 +113,5 @@
     while ((data=Next()))
     {
-        MDataChain *chain = new MDataChain(data->GetName());
+        MDataPhrase *chain = new MDataPhrase(data->GetName());
         if (!chain->PreProcess(plist))
         {
Index: trunk/MagicSoft/Mars/mhbase/MHMatrix.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MHMatrix.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/mhbase/MHMatrix.cc	(revision 8074)
@@ -30,5 +30,5 @@
 //
 // This is a histogram container which holds a matrix with one column per
-// data variable. The data variable can be a complex rule (MDataChain).
+// data variable. The data variable can be a complex rule (MDataPhrase).
 // Each event for wich Fill is called (by MFillH) is added as a new
 // row to the matrix.
Index: trunk/MagicSoft/Mars/mtools/MChisqEval.cc
===================================================================
--- trunk/MagicSoft/Mars/mtools/MChisqEval.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/mtools/MChisqEval.cc	(revision 8074)
@@ -37,5 +37,5 @@
 #include "MLogManip.h"
 
-#include "MDataChain.h"
+#include "MDataPhrase.h"
 #include "MParameters.h" // MParameterD
 
@@ -101,10 +101,10 @@
 void MChisqEval::SetY1(const TString data)
 {
-    SetY1(new MDataChain(data));
+    SetY1(new MDataPhrase(data));
 }
 
 void MChisqEval::SetY2(const TString data)
 {
-    SetY2(new MDataChain(data));
+    SetY2(new MDataPhrase(data));
 }
 

Index: trunk/MagicSoft/Mars/mdata/MDataArray.cc
===================================================================
--- trunk/MagicSoft/Mars/mdata/MDataArray.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/mdata/MDataArray.cc	(revision 8074)
@@ -38,5 +38,5 @@
 #include "MLogManip.h"
 
-#include "MDataChain.h"
+#include "MDataPhrase.h"
 
 ClassImp(MDataArray);
@@ -80,9 +80,9 @@
 // --------------------------------------------------------------------------
 //
 // Add a new data rule as a new entry (MDataChain)
 //
 void MDataArray::AddEntry(const TString rule)
 {
-    TObject *obj = new MDataChain(rule);
+    TObject *obj = new MDataPhrase(rule);
     obj->SetBit(kCanDelete);
     fList.Add(obj);
@@ -111,5 +111,5 @@
 Int_t MDataArray::FindRule(const char *rule) const
 {
-    const MDataChain data(rule);
+    const MDataPhrase data(rule);
     if (!data.IsValid())
         return -1;
@@ -80,9 +80,9 @@
 // --------------------------------------------------------------------------
 //
-// Add a new data rule as a new entry (MDataChain)
+// Add a new data rule as a new entry (MDataPhrase)
 //
 void MDataArray::AddEntry(const TString rule)
Index: trunk/MagicSoft/Mars/mhbase/MFillH.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MFillH.cc	(revision 8073)
+++ trunk/MagicSoft/Mars/mhbase/MFillH.cc	(revision 8074)
@@ -84,5 +84,5 @@
 #include <TCanvas.h>
 
-#include "MDataChain.h"
+#include "MDataPhrase.h"
 
 #include "MLog.h"
@@ -292,5 +292,5 @@
 //
 // If the histogram to be filles is a MHArray you can specify a 'rule'
 // This rule is used to create an MDataChain. The return value of the chain
 // is casted to int. Each int acts as a key. For each (new) key a new
 // histogram is created in the array. (eg for the rule
@@ -299,5 +299,5 @@
 void MFillH::SetRuleForIdx(const TString rule)
 {
-    fIndex = new MDataChain(rule);
+    fIndex = new MDataPhrase(rule);
     fIndex->SetBit(kCanDelete);
 }
@@ -562,5 +562,5 @@
 //    if (save && fCanvas)
 //        save->cd();
-    return rc;
+    return rc==kFALSE ? kCONTINUE : kTRUE;
 } 
 
@@ -292,5 +292,5 @@
 //
 // If the histogram to be filles is a MHArray you can specify a 'rule'
-// This rule is used to create an MDataChain. The return value of the chain
+// This rule is used to create an MDataPhrase. The return value of the chain
 // is casted to int. Each int acts as a key. For each (new) key a new
 // histogram is created in the array. (eg for the rule